<?php
/**
 * Theme functions and definitions
 *
 * @package Blogger_Era_Plus
 */

if ( ! function_exists( 'blogger_era_plus_enqueue_styles' ) ) :
	/**
	 * @since Insurance Gravity 1.0.0
	 */
	function blogger_era_plus_enqueue_styles() {
		wp_enqueue_style( 'blogger-era-plus-style-parent', get_template_directory_uri() . '/style.css' );		
		wp_enqueue_style( 'blogger-era-plus-style', get_stylesheet_directory_uri() . '/style.css', array( 'blogger-era-plus-style-parent' ), '1.0.0' );		

		wp_enqueue_style( 'blogger-era-plus-responsive-parent', get_template_directory_uri() . '/assets/css/responsive.css' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'blogger_era_plus_enqueue_styles', 99 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blogger_era_plus_widgets_init() {

	for ($i=1; $i < 5 ; $i++) { 
		register_sidebar( array(
			'name'          => sprintf( esc_html__( 'Footer %d', 'blogger-era-plus' ), absint( $i ) ),
			'id'            => 'footer-'.absint( $i ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		) );

	}						
}
add_action( 'widgets_init', 'blogger_era_plus_widgets_init' );


function blogger_era_plus_remove_footer() {
    remove_action( 'blogger_era_action_footer', 'blogger_era_footer_menu', 15 );    
}
add_action( 'init' , 'blogger_era_plus_remove_footer' );



if ( ! function_exists( 'blogger_era_footer_widget' ) ) :
	/**
	 * Footer Menu 
	 * @since 1.0.0
	 */
function blogger_era_footer_widget() {
	if ( is_active_sidebar( 'footer-1' ) || is_active_sidebar( 'footer-2' ) || is_active_sidebar( 'footer-3' ) || is_active_sidebar( 'footer-4' ) ) : ?>

		<aside class="footer-widget-area"> <!-- widget area starting from here -->
			<div class="container">
				<?php
				$column_count = 0;
				$class_coloumn =12;
				for ( $i = 1; $i < 5; $i++ ) {					
					if ( is_active_sidebar( 'footer-' . $i ) ) {
						$column_count++;
						$class_coloumn = 12/$column_count;
						
					}
				} ?>

				<?php $column_class = 'custom-col-' . absint( $class_coloumn );
				for ( $i = 1; $i < 5 ; $i++ ) {
					if ( is_active_sidebar( 'footer-' . absint($i ) ) ) { ?>
					<div class="<?php echo esc_attr( $column_class ); ?>">
						<?php dynamic_sidebar( 'footer-' . absint($i)); ?>
					</div>
					<?php }
				} ?>
			</div>

		</aside> <!-- widget area starting from here -->

	<?php endif;
}
endif;
add_filter( 'blogger_era_action_footer', 'blogger_era_footer_widget', 20);

if ( ! function_exists( 'blogger_era_footer_info' ) ) :
	/**
	 * Footer Credit 
	 * @since 1.0.0
	 */
	function blogger_era_footer_info() {	
	?>
		<div class="botton-footer">
			<?php 	// Powered by content.
			$powered_by_text = sprintf( __( 'Theme of %s', 'blogger-era-plus' ), '<a target="_blank" rel="designer" href="https://96themes.com/">96 THEME.</a>' );		
			?>
			<span class="copy-right"><?php echo wp_kses_post($powered_by_text);?></span>
		</div>
		<?php
	}
endif;
add_filter( 'blogger_era_action_footer', 'blogger_era_footer_info', 25);